<?php

namespace um_ext\um_profile_completeness\core;

if ( ! defined( 'ABSPATH' ) ) exit;

class Profile_Completeness_Shortcode {

	function __construct() {

		add_shortcode( 'ultimatemember_profile_completeness', array( &$this, 'ultimatemember_profile_completeness' ) );
		add_shortcode( 'ultimatemember_profile_progress_bar', array( &$this, 'ultimatemember_profile_progress_bar' ) );
		add_shortcode( 'um_profile_completeness_show_content', array( &$this, 'show_content' ) );

	}

	/***
	 ***    @Bar only widget
	 ***/
	function ultimatemember_profile_progress_bar( $args = array() ) {
		$defaults = array(
			'user_id' => get_current_user_id(),
			'who'     => 'loggedin',
		);
		$args = wp_parse_args( $args, $defaults );

		/**
		 * @var $user_id
		 * @var $who
		 */
		extract( $args );

		if (!$user_id || $who == 'loggedin') {
			$user_id = get_current_user_id();
		}

		if (in_array( $who, array( 'loggedin', 'admin' ) ) && um_profile_id() && $user_id != um_profile_id())
			return;

		$result = UM()->Profile_Completeness_API()->shortcode()->profile_progress( $user_id );
		if (!$result || $result['progress'] >= 100) return;

		return $result['bar'];
	}


	/**
	 * Completeness widget
	 *
	 * @param array $args
	 *
	 * @return string|void
	 */
	function ultimatemember_profile_completeness( $args = array() ) {
		if ( ! is_user_logged_in() ) {
			return '';
		}

		$requested_user_id = um_get_requested_user() ? um_get_requested_user() : get_current_user_id();
		$result = UM()->Profile_Completeness_API()->shortcode()->profile_progress( $requested_user_id );
		if ( ! $result || $result['progress'] >= 100 ) {
			return '';
		}

		$defaults = array();
		$args = wp_parse_args( $args, $defaults );
		extract( $args );

		if ( is_array( $result['steps'] ) ) {
			$result['steps'] = $this->reorder( $result['steps'] );
		}

		ob_start();

		include_once um_profile_completeness_path . 'templates/widget.php';
		$output = ob_get_clean();

		return $output;

		/*if ( isset( $args['is_page'] ) ) {
			echo include_once um_profile_completeness_path . 'templates/widget.php';
		} else {
			ob_start();
			include_once um_profile_completeness_path . 'templates/widget.php';
			$output = ob_get_contents();
			ob_end_clean();

			return $output;
		}

		return '';*/
	}

	/***
	 ***    @re-order profile completion steps
	 ***/
	function reorder( $steps ) {
		if (isset( $steps['profile_photo'] )) {
			$value = $steps['profile_photo'];
			unset( $steps['profile_photo'] );
			$steps['profile_photo'] = $value;
		}
		if (isset( $steps['cover_photo'] )) {
			$value = $steps['cover_photo'];
			unset( $steps['cover_photo'] );
			$steps['cover_photo'] = $value;
		}

		return $steps;
	}

	/***
	 ***    @Get progress result
	 ***/
	function profile_progress( $user_id ) {

		$get_progress = UM()->Profile_Completeness_API()->get_progress( $user_id );
		if ($get_progress == -1)
			return FALSE;

		$output['bar'] = '<span class="um-completeness-bar um-tip-n" title="' . sprintf( __( '%s Complete', 'um-profile-completeness' ), $get_progress['progress'] . '%' ) . '">';

		if ($get_progress['progress'] == 100) {
			$radius = '999px !important';
		} else {
			$radius = '999px 0 0 999px';
		}

		$output['bar'] .= '<span class="um-completeness-done" style="width: ' . $get_progress['progress'] . '%;border-radius: ' . $radius . '"></span>';

		for ($i = 0; $i <= 9; $i++) {
			$left = $i * 10;
			$output['bar'] .= '<span class="um-completeness-i" style="left: ' . $left . '%;"></span>';
		}

		$output['bar'] .= '</span>';

		$output['progress'] = $get_progress['progress'];
		$output['steps'] = $get_progress['steps'];
		$output['completed'] = ( isset( $get_progress['completed'] ) ) ? $get_progress['completed'] : '';
		$output['req_progress'] = $get_progress['req_progress'];
		$output['prevent_browse'] = $get_progress['prevent_browse'];
		$output['prevent_profileview'] = $get_progress['prevent_profileview'];
		$output['prevent_comment'] = $get_progress['prevent_comment'];
		$output['prevent_bb'] = $get_progress['prevent_bb'];
		$output['raw'] = $get_progress;
		return $output;
	}

	/**
	 * Show content on specific progress
	 *
	 * @param array $atts
	 * @param string $content
	 *
	 * @return string
	 */
	function show_content( $atts = array(), $content = '' ) {
		if ( ! is_user_logged_in() ) {
			return '';
		}

		$a = shortcode_atts( array(
			'user_id'  => get_current_user_id(),
			'who'      => 'loggedin',
			'role'     => um_user( 'role' ),
			'progress' => 100,
			'not'      => FALSE,
		), $atts );

		if ( $a['who'] == 'current_profile' ) {
			$a['user_id'] = um_profile_id();
		}

		$result = UM()->Profile_Completeness_API()->shortcode()->profile_progress( $a['user_id'] );

		if ( ! $result )
			return '';

		if ( $a['not'] ) {
			if ( $a['role'] == um_user( 'role' ) && $result['progress'] != $a['progress'] ) {
				return do_shortcode( $content );
			}
		} elseif ( $result['progress'] == $a['progress'] && $a['role'] == um_user( 'role' ) ) {
			return do_shortcode( $content );
		}

		return '';
	}
}